@@ -1,21 +1,9 @@
 /*
  *  alarmtimewidget.cpp  -  alarm date/time entry widget
  *  Program:  kalarm
- *  Copyright © 2001-2020 David Jarvie <djarvie@kde.org>
+ *  SPDX-FileCopyrightText: 2001-2020 David Jarvie <djarvie@kde.org>
  *
- *  This program is free software; you can redistribute it and/or modify
- *  it under the terms of the GNU General Public License as published by
- *  the Free Software Foundation; either version 2 of the License, or
- *  (at your option) any later version.
- *
- *  This program is distributed in the hope that it will be useful,
- *  but WITHOUT ANY WARRANTY; without even the implied warranty of
- *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
- *  GNU General Public License for more details.
- *
- *  You should have received a copy of the GNU General Public License along
- *  with this program; if not, write to the Free Software Foundation, Inc.,
- *  51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
+ *  SPDX-License-Identifier: GPL-2.0-or-later
  */
 
 #include "alarmtimewidget.h"
@@ -31,7 +19,6 @@
 #include "lib/timespinbox.h"
 #include "lib/timezonecombo.h"
 
-#include <KAlarmCal/DateTime>
 
 #include <KDateComboBox>
 #include <KLocalizedString>
@@ -42,6 +29,8 @@
 #include <QLabel>
 #include <QHBoxLayout>
 
+//clazy:excludeall=non-pod-global-static
+
 static const QTime time_23_59(23, 59);
 
 
@@ -94,7 +83,7 @@ void AlarmTimeWidget::init(Mode mode, const QString& title)
     mDeferring = mode & DEFER_TIME;
     mButtonGroup = new ButtonGroup(this);
     connect(mButtonGroup, &ButtonGroup::buttonSet, this, &AlarmTimeWidget::slotButtonSet);
-    QVBoxLayout* topLayout = new QVBoxLayout(topWidget);
+    auto* topLayout = new QVBoxLayout(topWidget);
     if (title.isEmpty())
         topLayout->setContentsMargins(0, 0, 0, 0);
 
@@ -110,13 +99,13 @@ void AlarmTimeWidget::init(Mode mode, const QString& title)
     mDateEdit->setOptions(KDateComboBox::EditDate | KDateComboBox::SelectDate | KDateComboBox::DatePicker);
     connect(mDateEdit, &KDateComboBox::dateEntered, this, &AlarmTimeWidget::dateTimeChanged);
     mDateEdit->setWhatsThis(xi18nc("@info:whatsthis",
-          "<para>Enter the date to schedule the alarm.</para>"
-          "<para>%1</para>", (mDeferring ? tzText : recurText)));
+                                   "<para>Enter the date to schedule the alarm.</para>"
+                                   "<para>%1</para>", (mDeferring ? tzText : recurText)));
     mAtTimeRadio->setFocusWidget(mDateEdit);
 
     // Time edit box and Any time checkbox
     QWidget* timeBox = new QWidget(topWidget);
-    QHBoxLayout* timeBoxHLayout = new QHBoxLayout(timeBox);
+    auto* timeBoxHLayout = new QHBoxLayout(timeBox);
     timeBoxHLayout->setContentsMargins(0, 0, 0, 0);
     timeBoxHLayout->setSpacing(2 * style()->pixelMetric(QStyle::PM_LayoutHorizontalSpacing));
     mTimeEdit = new TimeEdit(timeBox);
@@ -124,9 +113,9 @@ void AlarmTimeWidget::init(Mode mode, const QString& title)
     mTimeEdit->setFixedSize(mTimeEdit->sizeHint());
     connect(mTimeEdit, &TimeEdit::valueChanged, this, &AlarmTimeWidget::dateTimeChanged);
     mTimeEdit->setWhatsThis(xi18nc("@info:whatsthis",
-          "<para>Enter the time to schedule the alarm.</para>"
-          "<para>%1</para>"
-          "<para>%2</para>", (mDeferring ? tzText : recurText), TimeSpinBox::shiftWhatsThis()));
+                                   "<para>Enter the time to schedule the alarm.</para>"
+                                   "<para>%1</para>"
+                                   "<para>%2</para>", (mDeferring ? tzText : recurText), TimeSpinBox::shiftWhatsThis()));
 
     mAnyTime = -1;    // current status is uninitialised
     if (mode == DEFER_TIME)
@@ -156,13 +145,13 @@ void AlarmTimeWidget::init(Mode mode, const QString& title)
     mDelayTimeEdit = new TimeSpinBox(1, maxDelayTime, topWidget);
     mDelayTimeEdit->setValue(1439);
     mDelayTimeEdit->setFixedSize(mDelayTimeEdit->sizeHint());
-    connect(mDelayTimeEdit, static_cast<void (TimeSpinBox::*)(int)>(&TimeSpinBox::valueChanged), this, &AlarmTimeWidget::delayTimeChanged);
+    connect(mDelayTimeEdit, &TimeSpinBox::valueChanged, this, &AlarmTimeWidget::delayTimeChanged);
     mDelayTimeEdit->setWhatsThis(mDeferring ? xi18nc("@info:whatsthis", "<para>%1</para><para>%2</para>", i18n_TimeAfterPeriod(), TimeSpinBox::shiftWhatsThis())
                                             : xi18nc("@info:whatsthis", "<para>%1</para><para>%2</para><para>%3</para>", i18n_TimeAfterPeriod(), recurText, TimeSpinBox::shiftWhatsThis()));
     mAfterTimeRadio->setFocusWidget(mDelayTimeEdit);
 
     // Set up the layout, either narrow or wide
-    QGridLayout* grid = new QGridLayout();
+    auto* grid = new QGridLayout();
     grid->setContentsMargins(0, 0, 0, 0);
     topLayout->addLayout(grid);
     if (mDeferring)
@@ -172,7 +161,7 @@ void AlarmTimeWidget::init(Mode mode, const QString& title)
         grid->addWidget(timeBox, 1, 1, Qt::AlignLeft);
         grid->setColumnStretch(2, 1);
         topLayout->addStretch();
-        QHBoxLayout* layout = new QHBoxLayout();
+        auto* layout = new QHBoxLayout();
         topLayout->addLayout(layout);
         layout->addWidget(mAfterTimeRadio);
         layout->addWidget(mDelayTimeEdit);
@@ -197,20 +186,20 @@ void AlarmTimeWidget::init(Mode mode, const QString& title)
         grid->setColumnStretch(2, 1);
         topLayout->addStretch();
 
-        QHBoxLayout* layout = new QHBoxLayout();
+        auto* layout = new QHBoxLayout();
         topLayout->addLayout(layout);
         layout->setSpacing(2 * style()->pixelMetric(QStyle::PM_LayoutHorizontalSpacing));
 
         // Time zone selector
         mTimeZoneBox = new QWidget(topWidget);   // this is to control the QWhatsThis text display area
-        QHBoxLayout* hlayout = new QHBoxLayout(mTimeZoneBox);
+        auto* hlayout = new QHBoxLayout(mTimeZoneBox);
         hlayout->setContentsMargins(0, 0, 0, 0);
         QLabel* label = new QLabel(i18nc("@label:listbox", "Time zone:"), mTimeZoneBox);
         hlayout->addWidget(label);
         mTimeZone = new TimeZoneCombo(mTimeZoneBox);
         hlayout->addWidget(mTimeZone);
         mTimeZone->setMaxVisibleItems(15);
-        connect(mTimeZone, static_cast<void (TimeZoneCombo::*)(int)>(&TimeZoneCombo::activated), this, &AlarmTimeWidget::slotTimeZoneChanged);
+        connect(mTimeZone, &TimeZoneCombo::activated, this, &AlarmTimeWidget::slotTimeZoneChanged);
         mTimeZoneBox->setWhatsThis(i18nc("@info:whatsthis", "Select the time zone to use for this alarm."));
         label->setBuddy(mTimeZone);
         layout->addWidget(mTimeZoneBox);
@@ -273,6 +262,7 @@ KADateTime AlarmTimeWidget::getDateTime(int* minsFromNow, bool checkExpired, boo
     now.setTime(QTime(now.time().hour(), now.time().minute(), 0));
     if (!mAtTimeRadio->isChecked())
     {
+        // A relative time has been entered.
         if (!mDelayTimeEdit->isValid())
         {
             if (showErrorMessage)
@@ -281,14 +271,15 @@ KADateTime AlarmTimeWidget::getDateTime(int* minsFromNow, bool checkExpired, boo
                 *errorWidget = mDelayTimeEdit;
             return KADateTime();
         }
-        int delayMins = mDelayTimeEdit->value();
+        const int delayMins = mDelayTimeEdit->value();
         if (minsFromNow)
             *minsFromNow = delayMins;
         return now.addSecs(delayMins * 60).toTimeSpec(mTimeSpec);
     }
     else
     {
-        bool dateOnly = mAnyTimeAllowed && mAnyTimeCheckBox && mAnyTimeCheckBox->isChecked();
+        // An absolute time has been entered.
+        const bool dateOnly = mAnyTimeAllowed && mAnyTimeCheckBox && mAnyTimeCheckBox->isChecked();
         if (!mDateEdit->date().isValid()  ||  !mTimeEdit->isValid())
         {
             // The date and/or time is invalid
@@ -367,7 +358,7 @@ void AlarmTimeWidget::setDateTime(const DateTime& dt)
     }
     if (mAnyTimeCheckBox)
     {
-        bool dateOnly = dt.isDateOnly();
+        const bool dateOnly = dt.isDateOnly();
         if (dateOnly)
             mAnyTimeAllowed = true;
         mAnyTimeCheckBox->setChecked(dateOnly);
@@ -475,7 +466,7 @@ void AlarmTimeWidget::setMaxDelayTime(const KADateTime& now)
 */
 void AlarmTimeWidget::setAnyTime()
 {
-    int old = mAnyTime;
+    const int old = mAnyTime;
     mAnyTime = (mAtTimeRadio->isChecked() && mAnyTimeAllowed && mAnyTimeCheckBox && mAnyTimeCheckBox->isChecked()) ? 1 : 0;
     if (mAnyTime != old)
         Q_EMIT dateOnlyToggled(mAnyTime);
@@ -489,7 +480,7 @@ void AlarmTimeWidget::enableAnyTime(bool enable)
     if (mAnyTimeCheckBox)
     {
         mAnyTimeAllowed = enable;
-        bool at = mAtTimeRadio->isChecked();
+        const bool at = mAtTimeRadio->isChecked();
         mAnyTimeCheckBox->setEnabled(enable && at);
         if (at)
             mTimeEdit->setEnabled(!enable || !mAnyTimeCheckBox->isChecked());
@@ -550,14 +541,14 @@ void AlarmTimeWidget::updateTimes()
 */
 void AlarmTimeWidget::slotButtonSet(QAbstractButton*)
 {
-    bool at = mAtTimeRadio->isChecked();
+    const bool at = mAtTimeRadio->isChecked();
     mDateEdit->setEnabled(at);
     mTimeEdit->setEnabled(at && (!mAnyTimeAllowed || !mAnyTimeCheckBox || !mAnyTimeCheckBox->isChecked()));
     if (mAnyTimeCheckBox)
         mAnyTimeCheckBox->setEnabled(at && mAnyTimeAllowed);
     // Ensure that the value of the delay edit box is > 0.
     const KADateTime att(mDateEdit->date(), mTimeEdit->time(), mTimeSpec);
-    int minutes = (KADateTime::currentUtcDateTime().secsTo(att) + 59) / 60;
+    const int minutes = (KADateTime::currentUtcDateTime().secsTo(att) + 59) / 60;
     if (minutes <= 0)
         mDelayTimeEdit->setValid(true);
     mDelayTimeEdit->setEnabled(!at);
@@ -628,8 +619,8 @@ void AlarmTimeWidget::showMoreOptions(bool more)
 void AlarmTimeWidget::dateTimeChanged()
 {
     const KADateTime dt(mDateEdit->date(), mTimeEdit->time(), mTimeSpec);
-    int minutes = (KADateTime::currentUtcDateTime().secsTo(dt) + 59) / 60;
-    bool blocked = mDelayTimeEdit->signalsBlocked();
+    const int minutes = (KADateTime::currentUtcDateTime().secsTo(dt) + 59) / 60;
+    const bool blocked = mDelayTimeEdit->signalsBlocked();
     mDelayTimeEdit->blockSignals(true);     // prevent infinite recursion between here and delayTimeChanged()
     if (minutes <= 0  ||  minutes > mDelayTimeEdit->maximum())
         mDelayTimeEdit->setValid(false);
@@ -651,8 +642,8 @@ void AlarmTimeWidget::delayTimeChanged(int minutes)
     if (mDelayTimeEdit->isValid())
     {
         QDateTime dt = KADateTime::currentUtcDateTime().addSecs(minutes * 60).toTimeSpec(mTimeSpec).qDateTime();
-        bool blockedT = mTimeEdit->signalsBlocked();
-        bool blockedD = mDateEdit->signalsBlocked();
+        const bool blockedT = mTimeEdit->signalsBlocked();
+        const bool blockedD = mDateEdit->signalsBlocked();
         mTimeEdit->blockSignals(true);     // prevent infinite recursion between here and dateTimeChanged()
         mDateEdit->blockSignals(true);
         mTimeEdit->setValue(dt.time());
