@@ -1,21 +1,9 @@
 /*
  *  prefdlg.cpp  -  program preferences dialog
  *  Program:  kalarm
- *  Copyright © 2001-2020 David Jarvie <djarvie@kde.org>
+ *  SPDX-FileCopyrightText: 2001-2020 David Jarvie <djarvie@kde.org>
  *
- *  This program is free software; you can redistribute it and/or modify
- *  it under the terms of the GNU General Public License as published by
- *  the Free Software Foundation; either version 2 of the License, or
- *  (at your option) any later version.
- *
- *  This program is distributed in the hope that it will be useful,
- *  but WITHOUT ANY WARRANTY; without even the implied warranty of
- *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
- *  GNU General Public License for more details.
- *
- *  You should have received a copy of the GNU General Public License along
- *  with this program; if not, write to the Free Software Foundation, Inc.,
- *  51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
+ *  SPDX-License-Identifier: GPL-2.0-or-later
  */
 
 #include "prefdlg.h"
@@ -71,7 +59,6 @@ using namespace KHolidays;
 #include <KWindowInfo>
 #include <KWindowSystem>
 #endif
-#include <KToolInvocation>
 #include <KHelpClient>
 
 #include <QLabel>
@@ -152,6 +139,9 @@ KAlarmPrefDlg::KAlarmPrefDlg()
     setWindowTitle(i18nc("@title:window", "Configure"));
     setStandardButtons(QDialogButtonBox::Ok | QDialogButtonBox::Cancel | QDialogButtonBox::Help | QDialogButtonBox::RestoreDefaults | QDialogButtonBox::Apply);
     button(QDialogButtonBox::Ok)->setDefault(true);
+    button(QDialogButtonBox::RestoreDefaults)->setToolTip(KStandardGuiItem::defaults().toolTip());
+    button(QDialogButtonBox::Help)->setToolTip(KStandardGuiItem::help().toolTip());
+    button(QDialogButtonBox::Apply)->setToolTip(KStandardGuiItem::apply().toolTip());
     setFaceType(List);
     mTabScrollGroup = new StackedScrollGroup(this, this);
 
@@ -414,17 +404,18 @@ void PrefsTabBase::showEvent(QShowEvent*)
     {
         int wid = 0;
         int i;
-        const int end = mLabels.count();
-        QList<int> xpos;
-        for (i = 0;  i < end;  ++i)
+        const int labelCount = mLabels.count();
+        QVector<int> xpos;
+        xpos.reserve(labelCount);
+        for (const QLabel* label : qAsConst(mLabels))
         {
-            const int x = mLabels[i]->mapTo(this, QPoint(0, 0)).x();
+            const int x = label->mapTo(this, QPoint(0, 0)).x();
             xpos += x;
-            const int w = x + mLabels[i]->sizeHint().width();
+            const int w = x + label->sizeHint().width();
             if (w > wid)
                 wid = w;
         }
-        for (i = 0;  i < end;  ++i)
+        for (i = 0;  i < labelCount;  ++i)
         {
             mLabels[i]->setFixedWidth(wid - xpos[i]);
             mLabels[i]->setAlignment(Qt::AlignRight | Qt::AlignVCenter);
@@ -443,7 +434,7 @@ MiscPrefTab::MiscPrefTab(StackedScrollGroup* scrollGroup)
 {
     QGroupBox* group = new QGroupBox(i18nc("@title:group", "Run Mode"));
     topLayout()->addWidget(group);
-    QVBoxLayout* vlayout = new QVBoxLayout(group);
+    auto* vlayout = new QVBoxLayout(group);
 
     // Start at login
     mAutoStart = new QCheckBox(i18nc("@option:check", "Start at login"), group);
@@ -457,10 +448,20 @@ MiscPrefTab::MiscPrefTab(StackedScrollGroup* scrollGroup)
     mQuitWarn->setWhatsThis(xi18nc("@info:whatsthis", "Check to display a warning prompt before quitting <application>KAlarm</application>."));
     vlayout->addWidget(mQuitWarn, 0, Qt::AlignLeft);
 
-    // Confirm alarm deletion?
+    // Enable alarm names?
     QWidget* widget = new QWidget;  // this is for consistent left alignment
     topLayout()->addWidget(widget);
-    QHBoxLayout* hbox = new QHBoxLayout(widget);
+    auto* hbox = new QHBoxLayout(widget);
+    mUseAlarmNames = new QCheckBox(i18nc("@option:check", "Enable alarm names"));
+    mUseAlarmNames->setMinimumSize(mUseAlarmNames->sizeHint());
+    mUseAlarmNames->setWhatsThis(i18nc("@info:whatsthis", "Check to have the option to give alarms a name. This is a convenience to help you to identify alarms."));
+    hbox->addWidget(mUseAlarmNames);
+    hbox->addStretch();    // left adjust the controls
+
+    // Confirm alarm deletion?
+    widget = new QWidget;  // this is for consistent left alignment
+    topLayout()->addWidget(widget);
+    hbox = new QHBoxLayout(widget);
     mConfirmAlarmDeletion = new QCheckBox(i18nc("@option:check", "Confirm alarm deletions"));
     mConfirmAlarmDeletion->setMinimumSize(mConfirmAlarmDeletion->sizeHint());
     mConfirmAlarmDeletion->setWhatsThis(i18nc("@info:whatsthis", "Check to be prompted for confirmation each time you delete an alarm."));
@@ -485,7 +486,7 @@ MiscPrefTab::MiscPrefTab(StackedScrollGroup* scrollGroup)
     group = new QGroupBox(i18nc("@title:group", "Terminal for Command Alarms"));
     group->setWhatsThis(i18nc("@info:whatsthis", "Choose which application to use when a command alarm is executed in a terminal window"));
     topLayout()->addWidget(group);
-    QGridLayout* grid = new QGridLayout(group);
+    auto* grid = new QGridLayout(group);
     int row = 0;
 
     mXtermType = new ButtonGroup(group);
@@ -497,7 +498,7 @@ MiscPrefTab::MiscPrefTab(StackedScrollGroup* scrollGroup)
         const QStringList args = KShell::splitArgs(cmd);
         if (args.isEmpty()  ||  QStandardPaths::findExecutable(args[0]).isEmpty())
             continue;
-        QRadioButton* radio = new QRadioButton(args[0], group);
+        auto* radio = new QRadioButton(args[0], group);
         radio->setMinimumSize(radio->sizeHint());
         mXtermType->addButton(radio, mXtermCount);
         if (mXtermFirst < 0)
@@ -514,7 +515,7 @@ MiscPrefTab::MiscPrefTab(StackedScrollGroup* scrollGroup)
     }
 
     // QHBox used here doesn't allow the QLineEdit to expand!?
-    QHBoxLayout* hlayout = new QHBoxLayout();
+    auto* hlayout = new QHBoxLayout();
     grid->addLayout(hlayout, row + 1, 0, 1, 3, Qt::AlignLeft);
     QRadioButton* radio = new QRadioButton(i18nc("@option:radio Other terminal window command", "Other:"), group);
     hlayout->addWidget(radio);
@@ -539,6 +540,7 @@ void MiscPrefTab::restore(bool defaults, bool)
 {
     mAutoStart->setChecked(defaults ? true : Preferences::autoStart());
     mQuitWarn->setChecked(Preferences::quitWarn());
+    mUseAlarmNames->setChecked(Preferences::useAlarmName());
     mConfirmAlarmDeletion->setChecked(Preferences::confirmAlarmDeletion());
     mDefaultDeferTime->setValue(Preferences::defaultDeferTime());
     QString xtermCmd = Preferences::cmdXTermCommand();
@@ -599,6 +601,9 @@ void MiscPrefTab::apply(bool syncToDisc)
             Preferences::setNoAutoStart(false);
         Preferences::setAutoStartChangedByUser(true);  // prevent prompting the user on quit, about start-at-login
     }
+    b = mUseAlarmNames->isChecked();
+    if (b != Preferences::useAlarmName())
+        Preferences::setUseAlarmName(b);
     b = mConfirmAlarmDeletion->isChecked();
     if (b != Preferences::confirmAlarmDeletion())
         Preferences::setConfirmAlarmDeletion(b);
@@ -635,13 +640,13 @@ TimePrefTab::TimePrefTab(StackedScrollGroup* scrollGroup)
     : PrefsTabBase(scrollGroup)
 {
     // Default time zone
-    QHBoxLayout* itemBox = new QHBoxLayout();
+    auto* itemBox = new QHBoxLayout();
     itemBox->setContentsMargins(0, 0, 0, 0);
-    qobject_cast<QBoxLayout*>(topLayout())->addLayout(itemBox);
+    topLayout()->addLayout(itemBox);
 
     QWidget* widget = new QWidget; // this is to control the QWhatsThis text display area
     itemBox->addWidget(widget);
-    QHBoxLayout* box =  new QHBoxLayout(widget);
+    auto* box =  new QHBoxLayout(widget);
     box->setContentsMargins(0, 0, 0, 0);
     QLabel* label = new QLabel(i18nc("@label:listbox", "Time zone:"));
     box->addWidget(label);
@@ -658,7 +663,7 @@ TimePrefTab::TimePrefTab(StackedScrollGroup* scrollGroup)
     // Holiday region
     itemBox = new QHBoxLayout();
     itemBox->setContentsMargins(0, 0, 0, 0);
-    qobject_cast<QBoxLayout*>(topLayout())->addLayout(itemBox);
+    topLayout()->addLayout(itemBox);
 
     widget = new QWidget;    // this is to control the QWhatsThis text display area
     itemBox->addWidget(widget);
@@ -695,7 +700,7 @@ TimePrefTab::TimePrefTab(StackedScrollGroup* scrollGroup)
     // Start-of-day time
     itemBox = new QHBoxLayout();
     itemBox->setContentsMargins(0, 0, 0, 0);
-    qobject_cast<QBoxLayout*>(topLayout())->addLayout(itemBox);
+    topLayout()->addLayout(itemBox);
 
     widget = new QWidget;   // this is to control the QWhatsThis text display area
     itemBox->addWidget(widget);
@@ -719,7 +724,7 @@ TimePrefTab::TimePrefTab(StackedScrollGroup* scrollGroup)
 
     QWidget* daybox = new QWidget(group);   // this is to control the QWhatsThis text display area
     layout->addWidget(daybox);
-    QGridLayout* wgrid = new QGridLayout(daybox);
+    auto* wgrid = new QGridLayout(daybox);
     const QLocale locale;
     for (int i = 0;  i < 7;  ++i)
     {
@@ -826,7 +831,7 @@ void TimePrefTab::apply(bool syncToDisc)
     QBitArray workDays(7);
     for (int i = 0;  i < 7;  ++i)
         if (mWorkDays[i]->isChecked())
-            workDays.setBit(Locale::localeDayInWeek_to_weekDay(i) - 1, 1);
+            workDays.setBit(Locale::localeDayInWeek_to_weekDay(i) - 1, true);
     Preferences::setWorkDays(workDays);
     Preferences::setKOrgEventDuration(mKOrgEventDuration->value());
     t = mKOrgEventDuration->value();
@@ -846,7 +851,7 @@ StorePrefTab::StorePrefTab(StackedScrollGroup* scrollGroup)
     // Which resource to save to
     QGroupBox* group = new QGroupBox(i18nc("@title:group", "New Alarms && Templates"));
     topLayout()->addWidget(group);
-    QButtonGroup* bgroup = new QButtonGroup(group);
+    auto* bgroup = new QButtonGroup(group);
     QBoxLayout* layout = new QVBoxLayout(group);
 
     mDefaultResource = new QRadioButton(i18nc("@option:radio", "Store in default calendar"), group);
@@ -863,7 +868,7 @@ StorePrefTab::StorePrefTab(StackedScrollGroup* scrollGroup)
     // Archived alarms
     group = new QGroupBox(i18nc("@title:group", "Archived Alarms"));
     topLayout()->addWidget(group);
-    QGridLayout* grid = new QGridLayout(group);
+    auto* grid = new QGridLayout(group);
     grid->setColumnStretch(1, 1);
     grid->setColumnMinimumWidth(0, gridIndentWidth());
     mKeepArchived = new QCheckBox(i18nc("@option:check", "Keep alarms after expiry"), group);
@@ -873,7 +878,7 @@ StorePrefTab::StorePrefTab(StackedScrollGroup* scrollGroup)
     grid->addWidget(mKeepArchived, 0, 0, 1, 2, Qt::AlignLeft);
 
     QWidget* widget = new QWidget;
-    QHBoxLayout* box = new QHBoxLayout(widget);
+    auto* box = new QHBoxLayout(widget);
     box->setContentsMargins(0, 0, 0, 0);
     mPurgeArchived = new QCheckBox(i18nc("@option:check", "Discard archived alarms after:"));
     mPurgeArchived->setMinimumSize(mPurgeArchived->sizeHint());
@@ -975,7 +980,7 @@ EmailPrefTab::EmailPrefTab(StackedScrollGroup* scrollGroup)
 {
     QWidget* widget = new QWidget;
     topLayout()->addWidget(widget);
-    QHBoxLayout* box = new QHBoxLayout(widget);
+    auto* box = new QHBoxLayout(widget);
     box->setSpacing(2 * style()->pixelMetric(QStyle::PM_LayoutHorizontalSpacing));
     QLabel* label = new QLabel(i18nc("@label", "Email client:"));
     box->addWidget(label);
@@ -1019,7 +1024,7 @@ EmailPrefTab::EmailPrefTab(StackedScrollGroup* scrollGroup)
     // Your Email Address group box
     QGroupBox* group = new QGroupBox(i18nc("@title:group", "Your Email Address"));
     topLayout()->addWidget(group);
-    QGridLayout* grid = new QGridLayout(group);
+    auto* grid = new QGridLayout(group);
     grid->setColumnStretch(2, 1);
 
     // 'From' email address controls ...
@@ -1203,21 +1208,36 @@ EditPrefTab::EditPrefTab(StackedScrollGroup* scrollGroup)
 
     mTabs = new QTabWidget();
     topLayout()->addWidget(mTabs);
-    StackedGroupT<QWidget>* tabgroup = new StackedGroupT<QWidget>(mTabs);
+    auto* tabgroup = new StackedGroupT<QWidget>(mTabs);
 
-    StackedWidgetT<QWidget>* topGeneral = new StackedWidgetT<QWidget>(tabgroup);
-    QVBoxLayout* tgLayout = new QVBoxLayout(topGeneral);
+    auto* topGeneral = new StackedWidgetT<QWidget>(tabgroup);
+    auto* tgLayout = new QVBoxLayout(topGeneral);
     mTabGeneral = mTabs->addTab(topGeneral, i18nc("@title:tab", "General"));
 
-    StackedWidgetT<QWidget>* topTypes = new StackedWidgetT<QWidget>(tabgroup);
-    QVBoxLayout* ttLayout = new QVBoxLayout(topTypes);
+    auto* topTypes = new StackedWidgetT<QWidget>(tabgroup);
+    auto* ttLayout = new QVBoxLayout(topTypes);
     mTabTypes = mTabs->addTab(topTypes, i18nc("@title:tab", "Alarm Types"));
 
-    StackedWidgetT<QWidget>* topFontColour = new StackedWidgetT<QWidget>(tabgroup);
-    QVBoxLayout* tfLayout = new QVBoxLayout(topFontColour);
+    auto* topFontColour = new StackedWidgetT<QWidget>(tabgroup);
+    auto* tfLayout = new QVBoxLayout(topFontColour);
     mTabFontColour = mTabs->addTab(topFontColour, i18nc("@title:tab", "Font && Color"));
 
     // MISCELLANEOUS
+    // Alarm message display method
+    QWidget* widget = new QWidget;   // this is to control the QWhatsThis text display area
+    tgLayout->addWidget(widget);
+    auto* box = new QHBoxLayout(widget);
+    box->setContentsMargins(0, 0, 0, 0);
+    QLabel* label = new QLabel(EditDisplayAlarmDlg::i18n_lbl_DisplayMethod());
+    box->addWidget(label);
+    mDisplayMethod = new QComboBox();
+    mDisplayMethod->addItem(EditDisplayAlarmDlg::i18n_combo_Window());
+    mDisplayMethod->addItem(EditDisplayAlarmDlg::i18n_combo_Notify());
+    box->addWidget(mDisplayMethod);
+    box->addStretch();
+    label->setBuddy(mDisplayMethod);
+    widget->setWhatsThis(i18nc("@info:whatsthis", "The default setting for the alarm message display method in the alarm edit dialog."));
+
     // Show in KOrganizer
     mCopyToKOrganizer = new QCheckBox(EditAlarmDlg::i18n_chk_ShowInKOrganizer());
     mCopyToKOrganizer->setMinimumSize(mCopyToKOrganizer->sizeHint());
@@ -1225,9 +1245,9 @@ EditPrefTab::EditPrefTab(StackedScrollGroup* scrollGroup)
     tgLayout->addWidget(mCopyToKOrganizer);
 
     // Late cancellation
-    QWidget* widget = new QWidget;
+    widget = new QWidget;
     tgLayout->addWidget(widget);
-    QHBoxLayout* box = new QHBoxLayout(widget);
+    box = new QHBoxLayout(widget);
     box->setContentsMargins(0, 0, 0, 0);
     box->setSpacing(0);
     mLateCancel = new QCheckBox(LateCancelSelector::i18n_chk_CancelIfLate());
@@ -1240,7 +1260,7 @@ EditPrefTab::EditPrefTab(StackedScrollGroup* scrollGroup)
     tgLayout->addWidget(widget);
     box = new QHBoxLayout(widget);
     box->setContentsMargins(0, 0, 0, 0);
-    QLabel* label = new QLabel(i18nc("@label:listbox", "Recurrence:"));
+    label = new QLabel(i18nc("@label:listbox", "Recurrence:"));
     box->addWidget(label);
     mRecurPeriod = new ComboBox();
     mRecurPeriod->addItem(RecurrenceEdit::i18n_combo_NoRecur());
@@ -1258,7 +1278,7 @@ EditPrefTab::EditPrefTab(StackedScrollGroup* scrollGroup)
     // How to handle February 29th in yearly recurrences
     QWidget* febBox = new QWidget;  // this is to control the QWhatsThis text display area
     tgLayout->addWidget(febBox);
-    QVBoxLayout* vbox = new QVBoxLayout(febBox);
+    auto* vbox = new QVBoxLayout(febBox);
     vbox->setContentsMargins(0, 0, 0, 0);
     label = new QLabel(i18nc("@label", "In non-leap years, repeat yearly February 29th alarms on:"));
     label->setAlignment(Qt::AlignLeft);
@@ -1293,7 +1313,7 @@ EditPrefTab::EditPrefTab(StackedScrollGroup* scrollGroup)
     // DISPLAY ALARMS
     QGroupBox* group = new QGroupBox(i18nc("@title:group", "Display Alarms"));
     ttLayout->addWidget(group);
-    QVBoxLayout* vlayout = new QVBoxLayout(group);
+    auto* vlayout = new QVBoxLayout(group);
 
     mConfirmAck = new QCheckBox(EditDisplayAlarmDlg::i18n_chk_ConfirmAck());
     mConfirmAck->setMinimumSize(mConfirmAck->sizeHint());
@@ -1326,7 +1346,7 @@ EditPrefTab::EditPrefTab(StackedScrollGroup* scrollGroup)
     ttLayout->addWidget(bbox);
     vlayout = new QVBoxLayout(bbox);
 
-    QHBoxLayout* hlayout = new QHBoxLayout;
+    auto* hlayout = new QHBoxLayout;
     hlayout->setContentsMargins(0, 0, 0, 0);
     vlayout->addLayout(hlayout);
     mSound = new QComboBox();
@@ -1404,6 +1424,7 @@ void EditPrefTab::restore(bool, bool allTabs)
     int index;
     if (allTabs  ||  mTabs->currentIndex() == mTabGeneral)
     {
+        mDisplayMethod->setCurrentIndex(Preferences::defaultDisplayMethod() == Preferences::Display_Window ? 0 : 1);
         mCopyToKOrganizer->setChecked(Preferences::defaultCopyToKOrganizer());
         mLateCancel->setChecked(Preferences::defaultLateCancel());
         switch (Preferences::defaultRecurPeriod())
@@ -1517,6 +1538,15 @@ void EditPrefTab::apply(bool syncToDisc)
     b = mEmailBcc->isChecked();
     if (b != Preferences::defaultEmailBcc())
         Preferences::setDefaultEmailBcc(b);
+    Preferences::DisplayMethod disp;
+    switch(mDisplayMethod->currentIndex())
+    {
+        case 1:  disp = Preferences::Display_Notification; break;
+        case 0:
+        default: disp = Preferences::Display_Window; break;
+    }
+    if (disp != Preferences::defaultDisplayMethod())
+        Preferences::setDefaultDisplayMethod(disp);
     b = mCopyToKOrganizer->isChecked();
     if (b != Preferences::defaultCopyToKOrganizer())
         Preferences::setDefaultCopyToKOrganizer(b);
@@ -1597,11 +1627,11 @@ ViewPrefTab::ViewPrefTab(StackedScrollGroup* scrollGroup)
     topLayout()->addWidget(mTabs);
 
     QWidget* widget = new QWidget;
-    QVBoxLayout* topGeneral = new QVBoxLayout(widget);
+    auto* topGeneral = new QVBoxLayout(widget);
     mTabGeneral = mTabs->addTab(widget, i18nc("@title:tab", "General"));
 
     widget =  new QWidget;
-    QVBoxLayout* topWindows = new QVBoxLayout(widget);
+    auto* topWindows = new QVBoxLayout(widget);
     mTabWindows = mTabs->addTab(widget, i18nc("@title:tab", "Alarm Windows"));
 
     // Run-in-system-tray check box or group.
@@ -1616,7 +1646,7 @@ ViewPrefTab::ViewPrefTab(StackedScrollGroup* scrollGroup)
         // icons, so don't show options to hide the system tray icon.
         widget = new QWidget;  // this is to allow left adjustment
         topGeneral->addWidget(widget);
-        QHBoxLayout* box = new QHBoxLayout(widget);
+        auto* box = new QHBoxLayout(widget);
         mShowInSystemTrayCheck = new QCheckBox(showInSysTrayText);
         mShowInSystemTrayCheck->setWhatsThis(showInSysTrayWhatsThis);
         box->addWidget(mShowInSystemTrayCheck);
@@ -1629,7 +1659,7 @@ ViewPrefTab::ViewPrefTab(StackedScrollGroup* scrollGroup)
         mShowInSystemTrayGroup->setCheckable(true);
         mShowInSystemTrayGroup->setWhatsThis(showInSysTrayWhatsThis);
         topGeneral->addWidget(mShowInSystemTrayGroup);
-        QGridLayout* grid = new QGridLayout(mShowInSystemTrayGroup);
+        auto* grid = new QGridLayout(mShowInSystemTrayGroup);
         grid->setColumnStretch(1, 1);
         grid->setColumnMinimumWidth(0, gridIndentWidth());
 
@@ -1671,7 +1701,7 @@ ViewPrefTab::ViewPrefTab(StackedScrollGroup* scrollGroup)
     // System tray tooltip group box
     QGroupBox* group = new QGroupBox(i18nc("@title:group", "System Tray Tooltip"));
     topGeneral->addWidget(group);
-    QGridLayout* grid = new QGridLayout(group);
+    auto* grid = new QGridLayout(group);
     grid->setColumnStretch(2, 1);
     grid->setColumnMinimumWidth(0, gridIndentWidth());
     grid->setColumnMinimumWidth(1, gridIndentWidth());
@@ -1684,7 +1714,7 @@ ViewPrefTab::ViewPrefTab(StackedScrollGroup* scrollGroup)
     grid->addWidget(mTooltipShowAlarms, 0, 0, 1, 3, Qt::AlignLeft);
 
     widget = new QWidget;
-    QHBoxLayout* box = new QHBoxLayout(widget);
+    auto* box = new QHBoxLayout(widget);
     box->setContentsMargins(0, 0, 0, 0);
     mTooltipMaxAlarms = new QCheckBox(i18nc("@option:check", "Maximum number of alarms to show:"));
     mTooltipMaxAlarms->setMinimumSize(mTooltipMaxAlarms->sizeHint());
@@ -1725,8 +1755,8 @@ ViewPrefTab::ViewPrefTab(StackedScrollGroup* scrollGroup)
 
     group = new QGroupBox(i18nc("@title:group", "Alarm List"));
     topGeneral->addWidget(group);
-    QHBoxLayout* hlayout = new QHBoxLayout(group);
-    QVBoxLayout* colourLayout = new QVBoxLayout();
+    auto* hlayout = new QHBoxLayout(group);
+    auto* colourLayout = new QVBoxLayout();
     colourLayout->setContentsMargins(0, 0, 0, 0);
     hlayout->addLayout(colourLayout);
 
