@@ -1,21 +1,9 @@
 /*
  *  calendarupdater.cpp  -  base class to update a calendar to current KAlarm format
  *  Program:  kalarm
- *  Copyright © 2020 David Jarvie <djarvie@kde.org>
+ *  SPDX-FileCopyrightText: 2020 David Jarvie <djarvie@kde.org>
  *
- *  This program is free software; you can redistribute it and/or modify
- *  it under the terms of the GNU General Public License as published by
- *  the Free Software Foundation; either version 2 of the License, or
- *  (at your option) any later version.
- *
- *  This program is distributed in the hope that it will be useful,
- *  but WITHOUT ANY WARRANTY; without even the implied warranty of
- *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
- *  GNU General Public License for more details.
- *
- *  You should have received a copy of the GNU General Public License along
- *  with this program; if not, write to the Free Software Foundation, Inc.,
- *  51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
+ *  SPDX-License-Identifier: GPL-2.0-or-later
  */
 
 #include "calendarupdater.h"
@@ -53,7 +41,7 @@ CalendarUpdater::~CalendarUpdater()
 
 bool CalendarUpdater::containsResource(ResourceId id)
 {
-    for (CalendarUpdater* instance : mInstances)
+    for (CalendarUpdater* instance : qAsConst(mInstances))
     {
         if (instance->mResourceId == id)
             return true;
