@@ -1,21 +1,9 @@
 /*
  *  fileresource.cpp  -  base class for calendar resource accessed via file system
  *  Program:  kalarm
- *  Copyright © 2006-2020 David Jarvie <djarvie@kde.org>
+ *  SPDX-FileCopyrightText: 2006-2020 David Jarvie <djarvie@kde.org>
  *
- *  This program is free software; you can redistribute it and/or modify
- *  it under the terms of the GNU General Public License as published by
- *  the Free Software Foundation; either version 2 of the License, or
- *  (at your option) any later version.
- *
- *  This program is distributed in the hope that it will be useful,
- *  but WITHOUT ANY WARRANTY; without even the implied warranty of
- *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
- *  GNU General Public License for more details.
- *
- *  You should have received a copy of the GNU General Public License along
- *  with this program; if not, write to the Free Software Foundation, Inc.,
- *  51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
+ *  SPDX-License-Identifier: GPL-2.0-or-later
  */
 
 #include "fileresource.h"
@@ -44,6 +32,18 @@ FileResource::~FileResource()
 
 bool FileResource::isValid() const
 {
+#ifdef DEBUG_DETAIL
+    if (!mSettings->isValid())
+        qDebug() << "FileResource::isValid:" << displayId() << "NO (mSettings)";
+    if (mStatus == Status::NotConfigured)
+        qDebug() << "FileResource::isValid:" << displayId() << "NO (Not configured)";
+    if (mStatus == Status::Closed)
+        qDebug() << "FileResource::isValid:" << displayId() << "NO (Closed)";
+    if (id() < 0)
+        qDebug() << "FileResource::isValid:" << displayId() << "NO (ID < 0)";
+    if (mSettings->id() != id())
+        qDebug() << "FileResource::isValid:" << displayId() << "NO (ID:" << id() << mSettings->id() << ")";
+#endif
     // The settings ID must not have changed since construction.
     return mSettings->isValid()
        &&  mStatus < Status::Unusable
